@@ -61,12 +61,6 @@ class Account(ModelBase):
     icon = None
     """Account icon URL"""
 
-    @property
-    def balance(self):
-        """Balance details of the account, represented by an `AccountBalance` object."""
-
-        return AccountBalance.from_dict(self.session, self.session._query_api_with_exception("/rest/accounts/%s/balance" % (str(self.account_id), )))
-
     @property
     def transactions(self):
         """An array of `Transaction` objects, one for each transaction on the account"""
